aboutsummaryrefslogtreecommitdiff
path: root/docs/assets/js
diff options
context:
space:
mode:
authorMark Otto <[email protected]>2017-03-20 23:04:14 -0700
committerMark Otto <[email protected]>2017-03-20 23:27:54 -0700
commit1ecb74e007b8f2c00f89ff083fb7732098d019f7 (patch)
tree37b169804b03fde647cf62ec99df333bf4f3fb66 /docs/assets/js
parentfcaf81003c8eeb6090b79384c63ca1aadea078cb (diff)
downloadbootstrap-1ecb74e007b8f2c00f89ff083fb7732098d019f7.tar.xz
bootstrap-1ecb74e007b8f2c00f89ff083fb7732098d019f7.zip
bump to jquery 3.2.1
Diffstat (limited to 'docs/assets/js')
-rw-r--r--docs/assets/js/vendor/jquery-slim.min.js37
1 files changed, 23 insertions, 14 deletions
diff --git a/docs/assets/js/vendor/jquery-slim.min.js b/docs/assets/js/vendor/jquery-slim.min.js
index 2dbefe93f..6cdf1eecf 100644
--- a/docs/assets/js/vendor/jquery-slim.min.js
+++ b/docs/assets/js/vendor/jquery-slim.min.js
@@ -1,5 +1,5 @@
/*!
- * jQuery JavaScript Library v3.2.0 -ajax,-ajax/jsonp,-ajax/load,-ajax/parseXML,-ajax/script,-ajax/var/location,-ajax/var/nonce,-ajax/var/rquery,-ajax/xhr,-manipulation/_evalUrl,-event/ajax,-effects,-effects/Tween,-effects/animatedSelector
+ * jQuery JavaScript Library v3.2.1 -ajax,-ajax/jsonp,-ajax/load,-ajax/parseXML,-ajax/script,-ajax/var/location,-ajax/var/nonce,-ajax/var/rquery,-ajax/xhr,-manipulation/_evalUrl,-event/ajax,-effects,-effects/Tween,-effects/animatedSelector
* https://jquery.com/
*
* Includes Sizzle.js
@@ -9,7 +9,7 @@
* Released under the MIT license
* https://jquery.org/license
*
- * Date: 2017-03-16T21:26Z
+ * Date: 2017-03-20T19:00Z
*/
( function( global, factory ) {
@@ -88,7 +88,7 @@ var support = {};
var
- version = "3.2.0 -ajax,-ajax/jsonp,-ajax/load,-ajax/parseXML,-ajax/script,-ajax/var/location,-ajax/var/nonce,-ajax/var/rquery,-ajax/xhr,-manipulation/_evalUrl,-event/ajax,-effects,-effects/Tween,-effects/animatedSelector",
+ version = "3.2.1 -ajax,-ajax/jsonp,-ajax/load,-ajax/parseXML,-ajax/script,-ajax/var/location,-ajax/var/nonce,-ajax/var/rquery,-ajax/xhr,-manipulation/_evalUrl,-event/ajax,-effects,-effects/Tween,-effects/animatedSelector",
// Define a local copy of jQuery
jQuery = function( selector, context ) {
@@ -5343,11 +5343,9 @@ jQuery.event = {
},
click: {
// For checkable types, fire native event so checked state will be right
trigger: function() {
- if ( rcheckableType.test( this.type ) &&
- this.click && nodeName( this, "input" ) ) {
-
+ if ( this.type === "checkbox" && this.click && nodeName( this, "input" ) ) {
this.click();
return false;
}
@@ -6167,6 +6165,11 @@ var getStyles = function( elem ) {
function curCSS( elem, name, computed ) {
var width, minWidth, maxWidth, ret,
+
+ // Support: Firefox 51+
+ // Retrieving style before computed somehow
+ // fixes an issue with getting wrong values
+ // on detached elements
style = elem.style;
computed = computed || getStyles( elem );
@@ -6355,6 +6358,12 @@ function getWidthOrHeight( elem, name, extra ) {
valueIsBorderBox = isBorderBox &&
( support.boxSizingReliable() || val === elem.style[ name ] );
+ // Fall back to offsetWidth/Height when value is "auto"
+ // This happens for inline elements with no explicit setting (gh-3571)
+ if ( val === "auto" ) {
+ val = elem[ "offset" + name[ 0 ].toUpperCase() + name.slice( 1 ) ];
+ }
+
// Normalize "", auto, and prepare for extra
val = parseFloat( val ) || 0;
@@ -8078,16 +8087,16 @@ jQuery.fn.extend( {
return arguments.length === 1 ?
this.off( selector, "**" ) :
this.off( types, selector || "**", fn );
- },
- holdReady: function( hold ) {
- if ( hold ) {
- jQuery.readyWait++;
- } else {
- jQuery.ready( true );
- }
}
} );
+jQuery.holdReady = function( hold ) {
+ if ( hold ) {
+ jQuery.readyWait++;
+ } else {
+ jQuery.ready( true );
+ }
+};
jQuery.isArray = Array.isArray;
jQuery.parseJSON = JSON.parse;
jQuery.nodeName = nodeName;
@@ -5343,11 +5343,9 @@ jQuery.event = {
},
click: {
- // For checkable types, fire native event so checked state will be right
+ // For checkbox, fire native event so checked state will be right
trigger: function() {